==> nextcloud-app-mail-1.4.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/lv.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-pasts",
    "Auto detect failed. Please use manual mode." : "Automātiski noteikt neizdevās. Lūdzu, izmantojiet manuālo režīmu.",
    "Updating account failed: " : "Neizdevās labot konts",
    "Creating account failed: " : "Konta izveide neizdevās:",
    "Embedded message %s" : "Iegultais ziņojums%s",
    "💌 A mail app for Nextcloud" : "Nextcloud E-pasta lietotne",
    "Auto" : "Automātiski",
    "Name" : "Nosaukums",
    "Mail Address" : "E-pasta adrese",
    "Password" : "Parole",
    "Manual" : "Manuāli",
    "IMAP Settings" : "IMAP iestatījumi",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP drošība",
    "None" : "Neviens",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP lietotājs",
    "IMAP Password" : "IMAP parole",
    "SMTP Settings" : "SMTP iestatījumi",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP drošība",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP lietotājs",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "Connect" : "Savienoties",
    "Add mail account" : "Pievienot e-pasta kontu",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Select account" : "Izvēlieties kontu",
    "Subject" : "Temats",
    "Add attachment from Files" : "Pievienot pielikumu no failiem",
    "Sending …" : "Sūta …",
    "Go back" : "Atpakaļ",
    "Retry" : "Mēģināt vēlreiz",
    "Message sent!" : "Vēstule aizsūtīta!",
    "Send" : "Sūtīt",
    "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
    "No messages in this folder" : "Šajā mapē nav neviens ziņojums",
    "Favorite" : "Favorīts",
    "Unselect" : "Noņemt atlasi",
    "Select" : "Atzīmēt",
    "Delete" : "Dzēst",
    "Important" : "Svarīgi",
    "Favorites" : "Favorīti",
    "Other" : "Cits",
    "to" : "kam",
    "cc" : "kopija",
    "Reply" : "Atbildēt",
    "Forward" : "Turpināt",
    "View source" : "Skatīt avotu",
    "Import into calendar" : "Importēt kalendārā",
    "Download attachment" : "Lejupielādēt pielikumu",
    "Save to Files" : "Saglabāt uz Datnes",
    "Unnamed" : "Nenosaukts",
    "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
    "Save all to Files" : "Saglabāt visu uz Datnes",
    "The images have been blocked to protect your privacy." : "Attēli tiek bloķēti, lai aizsargātu jūsu konfidencialitāti.",
    "Show images from this sender" : "Rādīt attēlus no šī sūtītāja",
    "New message" : "Jauna ziņa",
    "Settings" : "Iestatījumi",
    "Quota" : "Kvota",
    "Add folder" : "Pievienot mapi",
    "Remove account" : "Noņemt kontu",
    "Cancel" : "Atcelt",
    "Show all folders" : "Rādīt visas mapes",
    "Collapse folders" : "Sakļaut mapes",
    "Signature" : "Paraksts",
    "General" : "Vispārīgs",
    "User" : "Lietotājs",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Search" : "Meklēt",
    "Refresh" : "Atsvaidzināt",
    "Connect your mail account" : "Pievienojiet savu e-pasta kontu",
    "All" : "Visi",
    "Archive" : "Arhīvi",
    "Drafts" : "Melnraksti",
    "All inboxes" : "Visas iesūtnes",
    "Inbox" : "Iesūtne",
    "Junk" : "Nevēlams",
    "Sent" : "Izsūtne",
    "Trash" : "Miskaste",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
    "Error loading message" : "Kļūda ielādējot vēstuli",
    "Forwarding to %s" : "Pārsūtīt uz %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Noklikšķiniet šeit, ja netiekat pārvirzīts automātiski dažu sekunžu laikā.",
    "Redirect" : "Novirzīt",
    "The link leads to %s" : "Saite, kas ved uz %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ja nevēlaties apmeklēt šo lapu, varat atgriezties pie <a href=\"%s\">e-pasta</a>.",
    "Continue to %s" : "Turpināt %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-mail-1.5.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/lv.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "Automātiski noteikt neizdevās. Lūdzu, izmantojiet manuālo režīmu.",
    "Updating account failed: " : "Neizdevās labot konts",
    "Creating account failed: " : "Konta izveide neizdevās:",
    "Embedded message %s" : "Iegultais ziņojums%s",
    "Mails" : "E-pasta sūtījumi",
    "Mail" : "E-pasts",
    "💌 A mail app for Nextcloud" : "Nextcloud E-pasta lietotne",
    "Auto" : "Automātiski",
    "Name" : "Nosaukums",
    "Mail Address" : "E-pasta adrese",
    "Password" : "Parole",
    "Manual" : "Manuāli",
    "IMAP Settings" : "IMAP iestatījumi",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP drošība",
    "None" : "Neviens",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP lietotājs",
    "IMAP Password" : "IMAP parole",
    "SMTP Settings" : "SMTP iestatījumi",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP drošība",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP lietotājs",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "Connect" : "Savienoties",
    "Add mail account" : "Pievienot e-pasta kontu",
    "Select account" : "Izvēlieties kontu",
    "Subject" : "Temats",
    "Add attachment from Files" : "Pievienot pielikumu no failiem",
    "Sending …" : "Sūta …",
    "Go back" : "Atpakaļ",
    "Retry" : "Mēģināt vēlreiz",
    "Message sent!" : "Vēstule aizsūtīta!",
    "Send" : "Sūtīt",
    "Choose a file to add as attachment" : "Izvēlēties datni ko pievienot kā pielikumu",
    "No messages in this folder" : "Šajā mapē nav neviens ziņojums",
    "Unselect" : "Noņemt atlasi",
    "Select" : "Atzīmēt",
    "Delete" : "Dzēst",
    "Important" : "Svarīgi",
    "Favorites" : "Favorīti",
    "Other" : "Cits",
    "Attachments" : "Pielikumi",
    "Import into calendar" : "Importēt kalendārā",
    "Download attachment" : "Lejupielādēt pielikumu",
    "Save to Files" : "Saglabāt uz Datnes",
    "Unnamed" : "Nenosaukts",
    "Choose a folder to store the attachment in" : "Izvēlieties mapi, kurā saglabāt pielikumus",
    "Save all to Files" : "Saglabāt visu uz Datnes",
    "The images have been blocked to protect your privacy." : "Attēli tiek bloķēti, lai aizsargātu jūsu konfidencialitāti.",
    "Show images from this sender" : "Rādīt attēlus no šī sūtītāja",
    "New message" : "Jauna ziņa",
    "Settings" : "Iestatījumi",
    "Quota" : "Kvota",
    "Add folder" : "Pievienot mapi",
    "Saving" : "Saglabā",
    "Remove account" : "Noņemt kontu",
    "Cancel" : "Atcelt",
    "Show all folders" : "Rādīt visas mapes",
    "Collapse folders" : "Sakļaut mapes",
    "Delete folder" : "Dzēst mapi",
    "Signature" : "Paraksts",
    "Reply" : "Atbildēt",
    "Forward" : "Turpināt",
    "View source" : "Skatīt avotu",
    "General" : "Vispārīgs",
    "User" : "Lietotājs",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Keyboard shortcut" : "Tastatūras saīsne",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Search" : "Meklēt",
    "Refresh" : "Atsvaidzināt",
    "Connect your mail account" : "Pievienojiet savu e-pasta kontu",
    "All" : "Visi",
    "Archive" : "Arhīvi",
    "Drafts" : "Melnraksti",
    "All inboxes" : "Visas iesūtnes",
    "Inbox" : "Iesūtne",
    "Junk" : "Nevēlams",
    "Sent" : "Izsūtne",
    "Trash" : "Miskaste",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
    "Error loading message" : "Kļūda ielādējot vēstuli",
    "Forwarding to %s" : "Pārsūtīt uz %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Noklikšķiniet šeit, ja netiekat pārvirzīts automātiski dažu sekunžu laikā.",
    "Redirect" : "Novirzīt",
    "The link leads to %s" : "Saite, kas ved uz %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ja nevēlaties apmeklēt šo lapu, varat atgriezties pie <a href=\"%s\">e-pasta</a>.",
    "Continue to %s" : "Turpināt %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
